# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""change SendMessage qa_ready action to AnnounceQa action

Revision ID: ced8e001d262
Revises: acfdeb6777cb
Create Date: 2021-11-10 10:16:09.070171

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "ced8e001d262"
down_revision = "acfdeb6777cb"
branch_labels = None
depends_on = None


def upgrade():
    """
    Modify action that gets triggered on QA workflow complete;
    Change it to perform the AnnounceQa action instead of attempting to SendMessage with arguments qa_ready
    """
    op.execute(
        """
        UPDATE capability_state_actions SET action_type = 'AnnounceQa', arguments = null
            WHERE action_type = 'SendMessage'
                AND arguments = 'qa_ready'
                AND transition_id = (
                    SELECT transition_id FROM capability_state_transitions
                    WHERE pattern = 'type == workflow-complete'
                        AND capability_name = 'std_calibration'
                )
        """
    )


def downgrade():
    """
    Undo above change
    """
    op.execute(
        """
        UPDATE capability_state_actions SET action_type = 'SendMessage', arguments = 'qa_ready'
            WHERE action_type = 'AnnounceQa'
                AND arguments IS null
                AND transition_id = (
                    SELECT transition_id FROM capability_state_transitions
                    WHERE pattern = 'type == workflow-complete'
                        AND capability_name = 'std_calibration'
                )
        """
    )
